# Aion Xtensions Chronos

**Aion Xtensions Chronos** is a Python package that allows you to generate AX mappings based on modules and use case data. This tool can be used to automate the generation of AX identifiers (e.g., AX1, AX2, AX3...) and organize them into a structured format.

## Installation

You can install Aion Xtensions Chronos via pip:

```bash
pip install aion-xtensions-chronos
